@@ -45,7 +45,7 @@ DAYS = [
     ]
 
 AIGUILLIER_URL = CONFIG['AIGUILLIER']['url']
-URL = CONFIG['AIGUILLIER']['url_v2']
+URL_V2 = CONFIG['AIGUILLIER']['url_v2']
 AIGUILLIER_USERNAME = CONFIG['AIGUILLIER']['username']
 
 SERVICE_CODE = CONFIG['APP']['service_code']
