@@ -200,7 +200,7 @@ def get_history(customer_name, date):
         with records.Database(si_database_url()) as db:
             sql = (
                 "SELECT * FROM fup "
-                "WHERE datetime={date}::date "
+                "WHERE datetime='{date}'::date "
                 "AND customer='{name}') "
             ).format(name=customer_name, date=date)
             rows = db.query(sql)
@@ -517,7 +517,7 @@ def get_consommation_sum(customer, date):
             return total
     except Exception as e:
         operation = "fetch customer {} total consumption for the last 30days".format(customer)
-        LOGS.logger.error("Unable to {}".format(operation))
+        LOGS.logger.error("Unable to {}: {}".format(operation, str(e)))
         send_error_report(
             operation=operation,
             error=str(e)
